@@ -6,7 +6,7 @@ enum keyWords
     UNKNOWN = '?',            // for getopt
     ABOVE, ABSOLUTE, ALIGN, ANCIENT, ARC_COLOR, ARC_FILE, AUTO, AZIMUTHAL, 
     BACKGROUND, BASEMAG, BELOW, BODY, 
-    CENTER, CIRCLE, CLOUD_GAMMA, CLOUD_MAP, CLOUD_THRESHOLD, COLOR, CONFIG_FILE, 
+    CENTER, CIRCLE, CLOUD_GAMMA, CLOUD_MAP, CLOUD_SSEC, CLOUD_THRESHOLD, COLOR, CONFIG_FILE, 
     DATE, DATE_FORMAT, DAY_MAP, DELIMITER, DRAW_ORBIT, DYNAMIC_ORIGIN,
     ENDOFLINE, EPHEMERIS, 
     FONT, FONTSIZE, FORK, FOV, 
@@ -17,8 +17,8 @@ enum keyWords
     LABEL, LABELPOS, LABEL_STRING, LAMBERT, LANGUAGE, LATITUDE, LATLON, LBR, LEFT, LIGHT_TIME, LOCALTIME, LOGMAGSTEP, LONGITUDE, LOOKAT, 
     MAGNIFY, MAJOR, MAKECLOUDMAPS, MAP_BOUNDS, MARKER_BOUNDS, MARKER_COLOR, MARKER_FILE, MARKER_FONT, MAX_RAD_FOR_LABEL, MIN_RAD_FOR_LABEL, MIN_RAD_FOR_MARKERS, MERCATOR, MOLLWEIDE, MULTIPLE,
     NAME, NIGHT_MAP, NORTH, NUM_TIMES, 
-    OUTPUT, ORBIT, ORBIT_COLOR, ORIGIN, ORIGINFILE, ORTHOGRAPHIC, 
-    PANGO, PETERS, POSITION, POST_COMMAND, PREV_COMMAND, PROJECTION, 
+    ORBIT, ORBIT_COLOR, ORIGIN, ORIGINFILE, ORTHOGRAPHIC, OUTPUT, OUTPUT_START_INDEX, 
+    PANGO, PATH, PATH_RELATIVE_TO, PETERS, POSITION, POST_COMMAND, PREV_COMMAND, PROJECTION, 
     QUALITY, 
     RADIUS, RANDOM, RANDOM_ORIGIN, RANDOM_TARGET, RANGE, RECTANGULAR, RIGHT, ROOT, ROTATE, 
     SATELLITE_FILE, SAVE_DESKTOP_FILE, SEARCHDIR, SHADE, SPACING, SPECULAR_MAP, SPICE_EPHEMERIS, SPICE_FILE, STARFREQ, STARMAP, SYMBOLSIZE, SYSTEM, 
@@ -35,7 +35,7 @@ const char * const keyWordString[LAST_WORD] =
     "UNKNOWN",
     "ABOVE", "ABSOLUTE", "ALIGN", "ANCIENT", "ARC_COLOR", "ARC_FILE", "AUTO", "AZIMUTHAL", 
     "BACKGROUND", "BASEMAG", "BELOW", "BODY", 
-    "CENTER", "CIRCLE", "CLOUD_GAMMA", "CLOUD_MAP", "CLOUD_THRESHOLD", "COLOR", "CONFIG_FILE", 
+    "CENTER", "CIRCLE", "CLOUD_GAMMA", "CLOUD_MAP", "CLOUD_SSEC", "CLOUD_THRESHOLD", "COLOR", "CONFIG_FILE", 
     "DATE", "DATE_FORMAT", "DAY_MAP", "DELIMITER", "DRAW_ORBIT", "DYNAMIC_ORIGIN",
     "ENDOFLINE", "EPHEMERIS", 
     "FONT", "FONTSIZE", "FORK", "FOV", 
@@ -46,8 +46,8 @@ const char * const keyWordString[LAST_WORD] =
     "LABEL", "LABELPOS", "LABEL_STRING", "LAMBERT", "LANGUAGE", "LATITUDE", "LATLON", "LBR", "LEFT", "LIGHT_TIME", "LOCALTIME", "LOGMAGSTEP", "LONGITUDE", "LOOKAT", 
     "MAGNIFY", "MAJOR", "MAKECLOUDMAPS", "MAP_BOUNDS", "MARKER_BOUNDS", "MARKER_COLOR", "MARKER_FILE", "MARKER_FONT", "MAX_RAD_FOR_LABEL", "MIN_RAD_FOR_LABEL", "MIN_RAD_FOR_MARKERS", "MERCATOR", "MOLLWEIDE", "MULTIPLE",
     "NAME", "NIGHT_MAP", "NORTH", "NUM_TIMES", 
-    "OUTPUT", "ORBIT", "ORBIT_COLOR", "ORIGIN", "ORIGINFILE", "ORTHOGRAPHIC", 
-    "PANGO", "PETERS", "POSITION", "POST_COMMAND", "PREV_COMMAND", "PROJECTION", 
+    "ORBIT", "ORBIT_COLOR", "ORIGIN", "ORIGINFILE", "ORTHOGRAPHIC", "OUTPUT", "OUTPUT_START_INDEX", 
+    "PANGO", "PATH", "PATH_RELATIVE_TO", "PETERS", "POSITION", "POST_COMMAND", "PREV_COMMAND", "PROJECTION", 
     "QUALITY", 
     "RADIUS", "RANDOM", "RANDOM_ORIGIN", "RANDOM_TARGET", "RANGE", "RECTANGULAR", "RIGHT", "ROOT", "ROTATE", 
     "SATELLITE_FILE", "SAVE_DESKTOP_FILE", "SEARCHDIR", "SHADE", "SPACING", "SPECULAR_MAP", "SPICE_EPHEMERIS", "SPICE_FILE", "STARFREQ", "STARMAP", "SYMBOLSIZE", "SYSTEM", 
@@ -55,7 +55,7 @@ const char * const keyWordString[LAST_WORD] =
     "UTCLABEL", 
     "VERBOSITY", "VERSIONNUMBER", "VROOT", 
     "WAIT", "WINDOW", "WINDOWTITLE", 
-    "XWINID", 
+    "XWINID",
     "LAST_WORD"
 };
 
